@@ -29,10 +29,12 @@ _policy_fields = set([
     'detectMime',        # MimeType侦测开关
     'mimeLimit',         # MimeType限制
     'fsizeLimit',        # 上传文件大小限制
+    'fsizeMin',          # 上传文件最少字节数
 
     'persistentOps',        # 持久化处理操作
     'persistentNotifyUrl',  # 持久化处理结果通知URL
     'persistentPipeline',   # 持久化处理独享队列
+    'deleteAfterDays',      # 文件多少天后自动删除
 ])
 
 _deprecated_policy_fields = set([
